@@ -1,3 +1,14 @@
+(***********************************************************************)
+(*                                                                     *)
+(*                           Objective Caml                            *)
+(*                                                                     *)
+(*               Pierre Weis, projet Cristal, INRIA Rocquencourt       *)
+(*                                                                     *)
+(*  Copyright 2001 Institut National de Recherche en Informatique et   *)
+(*  en Automatique.  All rights reserved.  This file is distributed    *)
+(*  only by permission.                                                *)
+(*                                                                     *)
+(***********************************************************************)
 exception Trouv;;
 
 let caractre_dans_chane chane car =
@@ -514,7 +525,7 @@ let message s = print_string s; print_newline ();;
 let prix__payer = ref 0;;
 
 let bonjour () =
-    prix__payer := 200;
+    prix__payer := 30;
     message "\nBonjour, je m'appelle Camlia.";
     message "\nJe suis l pour vous aider  rsoudre \
                vos problmes psychologiques.";
@@ -526,12 +537,12 @@ let au_revoir () =
     message (au_choix_dans salutations);
     message "\nAu revoir ...\n";
     print_string "Vous me devez "; print_int !prix__payer;
-    message " francs. Chque  l'ordre de Camlia. Merci.";;
+    message " euros. Chque  l'ordre de Camlia. Merci.";;
 
 let rponse_du_patient = ref "";;
 
 let coute_le_patient () =
-    prix__payer := !prix__payer + 10;
+    prix__payer := !prix__payer + 2;
     print_string ">> ";
     rponse_du_patient := read_line ();;
 
