@@ -1,6 +1,6 @@
 /* La version C de la fonction determ__reconnait */
 
-#include "caml/mlvalues.h"
+#include "mlvalues.h"
 
 value reconnait(automate, chaine)
         value automate, chaine;
