@@ -15,7 +15,7 @@ compile "equation.ml";;
 #load "equation.cmo";;
 open Equation;;
 
-comple "order.ml";;
+compile "order.ml";;
 #load "order.cmo";;
 open Order;;
 
